==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var FilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterExpressionDescriptionMetadata, _super);
    function FilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterExpressionDescriptionMetadata.b = function (a) {
        if (FilterExpressionDescriptionMetadata.a == null) {
            FilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterExpressionDescriptionMetadata.c(FilterExpressionDescriptionMetadata.a);
        }
        if (a.g(FilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.s(FilterExpressionDescriptionMetadata.a);
    };
    FilterExpressionDescriptionMetadata.c = function (a) {
    };
    FilterExpressionDescriptionMetadata.d = function (a) {
        FilterExpressionDescriptionMetadata.b(a);
        a.t("FilterExpression", FilterExpressionDescriptionMetadata.a);
    };
    FilterExpressionDescriptionMetadata.$t = markType(FilterExpressionDescriptionMetadata, 'FilterExpressionDescriptionMetadata');
    FilterExpressionDescriptionMetadata.a = null;
    return FilterExpressionDescriptionMetadata;
}(Base));
export { FilterExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var FilterExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FilterExpressionDescriptionMetadata, _super);
    function FilterExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FilterExpressionDescriptionMetadata.b = function (a) {
        if (FilterExpressionDescriptionMetadata.a == null) {
            FilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FilterExpressionDescriptionMetadata.c(FilterExpressionDescriptionMetadata.a);
        }
        if (a.j(FilterExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(FilterExpressionDescriptionMetadata.a);
    };
    FilterExpressionDescriptionMetadata.c = function (a) {
    };
    FilterExpressionDescriptionMetadata.d = function (a) {
        FilterExpressionDescriptionMetadata.b(a);
        a.z("FilterExpression", FilterExpressionDescriptionMetadata.a);
    };
    FilterExpressionDescriptionMetadata.$t = markType(FilterExpressionDescriptionMetadata, 'FilterExpressionDescriptionMetadata');
    FilterExpressionDescriptionMetadata.a = null;
    return FilterExpressionDescriptionMetadata;
}(Base));
export { FilterExpressionDescriptionMetadata };
